==> airy-0.1.1.tar.gz: airy-0.1.1/airy/core/markup.py <==
from tornado.escape import to_unicode
from airy.utils.html import strip_tags
import logging
import re

_URL_RE = re.compile(ur"""\b((?:([\w-]+):(/{1,3})|www[.])(?:(?:(?:[^\s&()]|&amp;|&quot;)*(?:[^!"#$%&'()*+,.:;<=>?@\[\]^`{|}~\s]))|(?:\((?:[^\s&()]|&amp;|&quot;)*\)))+)""")

def linebreaks(text):
    """
    Turns every new-line ("\n") into a "<br />" HTML tag.
    """
    return to_unicode(text).replace('\n', '<br />')

def linkify(text, shorten=False, extra_params="",
            require_protocol=False, permitted_protocols=["http", "https"]):
    """Converts plain text into HTML with links.

    For example: ``linkify("Hello http://tornadoweb.org!")`` would return
    ``Hello <a href="http://tornadoweb.org">http://tornadoweb.org</a>!``

    Parameters:

    shorten: Long urls will be shortened for display.

    extra_params: Extra text to include in the link tag,
        e.g. linkify(text, extra_params='rel="nofollow" class="external"')

    require_protocol: Only linkify urls which include a protocol. If this is
        False, urls such as www.facebook.com will also be linkified.

    permitted_protocols: List (or set) of protocols which should be linkified,
        e.g. linkify(text, permitted_protocols=["http", "ftp", "mailto"]).
        It is very unsafe to include protocols such as "javascript".
    """
    if extra_params:
        extra_params = " " + extra_params.strip()

    def make_link(m):
        url = m.group(1)
        proto = m.group(2)
        if require_protocol and not proto:
            return url  # not protocol, no linkify

        if proto and proto not in permitted_protocols:
            return url  # bad protocol, no linkify

        href = m.group(1)
        if not proto:
            href = "http://" + href   # no proto specified, use http

        params = extra_params

        # clip long urls. max_len is just an approximation
        max_len = 30
        if shorten and len(url) > max_len:
            before_clip = url
            if proto:
                proto_len = len(proto) + 1 + len(m.group(3) or "")  # +1 for :
            else:
                proto_len = 0

            parts = url[proto_len:].split("/")
            if len(parts) > 1:
                # Grab the whole host part plus the first bit of the path
                # The path is usually not that interesting once shortened
                # (no more slug, etc), so it really just provides a little
                # extra indication of shortening.
                url = url[:proto_len] + parts[0] + "/" +\
                      parts[1][:8].split('?')[0].split('.')[0]

            if len(url) > max_len * 1.5:  # still too long
                url = url[:max_len]

            if url != before_clip:
                amp = url.rfind('&')
                # avoid splitting html char entities
                if amp > max_len - 5:
                    url = url[:amp]
                url += "..."

                if len(url) >= len(before_clip):
                    url = before_clip
                else:
                    # full url is visible on mouse-over (for those who don't
                    # have a status bar, such as Safari by default)
                    params += ' title="%s"' % href

        return u'<a href="%s"%s>%s</a>' % (href, params, url)

    # The regex is modified to avoid character entites other than &amp; so
    # that we won't pick up &quot;, etc.
    return _URL_RE.sub(make_link, text)

def sanitize(text):
    """
    Cleans up user input from potentially dangerous things,
    such as <script>, <img src="javascript:..." />, <a href="javascript:.."> etc.

    Please note, this function is **not 100% safe**.

    If want to ensure the input is safe it's best to just escape all HTML.

    If you decide to use ``markup,sanitize()`` make sure you have html5lib available on your system/project.
    """
    try:
        from airy.core import sanitizer
        return sanitizer.clean_html(text)
    except ImportError:
        logging.error("You need html5lib in order to use sanitize")
        return "ERROR: You need html5lib in order to use sanitize"

def truncate(text, limit=80):
    return text[:limit]+'...'

==> airy-0.1.3.tar.gz: airy-0.1.3/airy/core/markup.py <==
from tornado.escape import to_unicode
from airy.utils.html import strip_tags
import logging
import re

_URL_RE = re.compile(ur"""\b((?:([\w-]+):(/{1,3})|www[.])(?:(?:(?:[^\s&()]|&amp;|&quot;)*(?:[^!"#$%&'()*+,.:;<=>?@\[\]^`{|}~\s]))|(?:\((?:[^\s&()]|&amp;|&quot;)*\)))+)""")

_link_regexes = [
    re.compile(r'(?P<body>https?://(?P<host>[a-z0-9._-]+)(?:/[/\-_.,a-z0-9%&?;=~]*)?(?:\([/\-_.,a-z0-9%&?;=~]*\))?)', re.I),
    # This is conservative, but autolinking can be a bit conservative:
    re.compile(r'mailto:(?P<body>[a-z0-9._-]+@(?P<host>[a-z0-9_._]+[a-z]))', re.I),
    re.compile(r'(?P<body>www\.(?P<host>[a-z0-9._-]+)(?:/[/\-_.,a-z0-9%&?;=~]*)?(?:\([/\-_.,a-z0-9%&?;=~]*\))?)', re.I),
    ]

def linebreaks(text):
    """
    Turns every new-line ("\n") into a "<br />" HTML tag.
    """
    return to_unicode(text).replace('\n', '<br />')

def linkify(text, shorten=False, extra_params="",
            require_protocol=False, permitted_protocols=["http", "https"]):
    """Converts plain text into HTML with links.

    For example: ``linkify("Hello http://tornadoweb.org!")`` would return
    ``Hello <a href="http://tornadoweb.org">http://tornadoweb.org</a>!``

    Parameters:

    shorten: Long urls will be shortened for display.

    extra_params: Extra text to include in the link tag,
        e.g. linkify(text, extra_params='rel="nofollow" class="external"')

    require_protocol: Only linkify urls which include a protocol. If this is
        False, urls such as www.facebook.com will also be linkified.

    permitted_protocols: List (or set) of protocols which should be linkified,
        e.g. linkify(text, permitted_protocols=["http", "ftp", "mailto"]).
        It is very unsafe to include protocols such as "javascript".
    """
    if extra_params:
        extra_params = " " + extra_params.strip()

    def make_link(m):
        url = m.group(1)
        proto = m.group(2)
        if require_protocol and not proto:
            return url  # not protocol, no linkify

        if proto and proto not in permitted_protocols:
            return url  # bad protocol, no linkify

        href = m.group(1)
        if not proto:
            href = "http://" + href   # no proto specified, use http

        params = extra_params

        # clip long urls. max_len is just an approximation
        max_len = 30
        if shorten and len(url) > max_len:
            before_clip = url
            if proto:
                proto_len = len(proto) + 1 + len(m.group(3) or "")  # +1 for :
            else:
                proto_len = 0

            parts = url[proto_len:].split("/")
            if len(parts) > 1:
                # Grab the whole host part plus the first bit of the path
                # The path is usually not that interesting once shortened
                # (no more slug, etc), so it really just provides a little
                # extra indication of shortening.
                url = url[:proto_len] + parts[0] + "/" +\
                      parts[1][:8].split('?')[0].split('.')[0]

            if len(url) > max_len * 1.5:  # still too long
                url = url[:max_len]

            if url != before_clip:
                amp = url.rfind('&')
                # avoid splitting html char entities
                if amp > max_len - 5:
                    url = url[:amp]
                url += "..."

                if len(url) >= len(before_clip):
                    url = before_clip
                else:
                    # full url is visible on mouse-over (for those who don't
                    # have a status bar, such as Safari by default)
                    params += ' title="%s"' % href

        return u'<a href="%s"%s>%s</a>' % (href, params, url)

    try:
        from lxml.html.clean import autolink_html
        text = text.replace('http://www.', 'www.').replace('www.', 'http://www.')
        return autolink_html(text, _link_regexes)
    except ImportError:
        pass

    splitted_text = re.split("""(<a.*?>.*?</a>)""", text)
    for i in range(0, len(splitted_text), 2):
        splitted_text[i] = _URL_RE.sub(make_link, splitted_text[i])

    # The regex is modified to avoid character entites other than &amp; so
    # that we won't pick up &quot;, etc.
#    return _URL_RE.sub(make_link, text)
    return ''.join(splitted_text)

def sanitize(text):
    """
    Cleans up user input from potentially dangerous things,
    such as <script>, <img src="javascript:..." />, <a href="javascript:.."> etc.

    Please note, this function is **not 100% safe**.

    If want to ensure the input is safe it's best to just escape all HTML.

    If you decide to use ``markup,sanitize()`` make sure you have html5lib available on your system/project.
    """
    try:
        from airy.core import sanitizer
        return sanitizer.clean_html(text)
    except ImportError:
        logging.error("You need html5lib in order to use sanitize")
        return "ERROR: You need html5lib in order to use sanitize"

def truncate(text, limit=80):
    return text[:limit]+'...'
